==> astk-client-1.2.4.tbz: aster/ASTK/ASTK_CLIENT/lib/ASTK/init_agla.tcl <==
#########################################################################
# COPYRIGHT (C) 2003         EDF R&D              WWW.CODE-ASTER.ORG    #
#                                                                       #
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR         #
# MODIFY IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS        #
# PUBLISHED BY THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE    #
# LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.                       #
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,       #
# BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF        #
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      #
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              #
#                                                                       #
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     #
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO : EDF R&D CODE_ASTER,       #
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.        #
#########################################################################

# $Id: init_agla.tcl,v 1.15 2005/06/23 13:01:51 mcourtoi Exp $

# initialisation des variables de l'agla
#################################################################
proc init_agla { } {
   set astk::agla(status) off
   set astk::agla(instance) "UA"
   set astk::agla(mail_ata) ""
   set astk::agla(infoid) {}
   set astk::agla(num_serv) -1
   set astk::agla(nb_verdev) 0
   set astk::agla(verdev,0) ""
   set astk::agla(list_cua) {}
   set astk::agla(cua) ""
   # listes rcupres pour le REX
   set astk::rex(list_emet_nom) {}
   set astk::rex(list_emet_dpt) {}
   set astk::rex(list_corresp_nom) {}
   set astk::rex(list_corresp_dpt) {}
   set astk::rex(list_correct_nom) {}
   set astk::rex(list_correct_dpt) {}
}

# mise  jour des donnes de l'agla
#################################################################
proc raffr_agla { {parent "."} {REINI "DETR"} } {
   ashare::mess "info" 5
   init_agla

#  vrifie que mach_dev est parmi les serveurs configurs
   set pastrouve 1
   for {set i 0} {$i < $astk::config(nb_serv)} {incr i} {
      if { $astk::config($i,mach_ref) == "oui" } {
         set astk::agla(num_serv) $i
         set pastrouve 0
         break
      }
   }
# machine de rfrence pas dans les serveurs
#ou on ne veut pas rcuprer les infos
   if { $pastrouve } {
      ashare::mess "info" 7
   } elseif { $astk::recup == 0 } {
      ashare::mess "info" 40
   } else {
# machine de rfrence trouve
      set serv $astk::agla(num_serv)
   # instance de l'utilisateur
      set astk::agla(status) off
      recup_info $parent $serv
      if { [regexp "EDA" $astk::agla(instance)] } {
         set astk::agla(status) on
      }
      if { [regexp {EDA|CUA} $astk::agla(instance)] } {
         # il est son propre CUA
         set astk::config(-1,cua) $astk::config($serv,login)
      }
      # stocker le CUA et ORG dans les prefs
      set astk::config(-1,cua) [agla_cua_get $astk::config(-1,cua) 1]
      set astk::config(-1,org) [agla_cua_get $astk::config(-1,cua) 3]
      ashare::save_prefs

   # mail de l'assistance
      set astk::agla(mail_ata) [agla_cua_get "M.ASSISTANCE" 2 0]

   # faire la liste des versions (les NEW de $serv)
      set astk::agla(nb_verdev) 0
      for {set i 0} {$i < $astk::config($serv,nb_vers)} {incr i} {
         if { [regexp {^NEW} $astk::config($serv,vers,$i)] } {
            set astk::agla(verdev,$astk::agla(nb_verdev)) $astk::config($serv,vers,$i)
            incr astk::agla(nb_verdev)
         }
      }
      if { $ashare::dbg >= 4 } {
         ashare::log "<DEBUG> (raffr_agla) status:$astk::agla(status) num_serv:$astk::agla(num_serv) instance:$astk::agla(instance)"
      }
   }
# mise  jour des onglets
   if { $REINI != "INI" } {
      init_onglet "DETR"
   }
}

# retourne la valeur d'un champ pour le CUA
# dont le login est "valeur" (si crit=1, defaut)
# dont le nom est "valeur" (si crit=0)...
#  champ 0 : P.NOM, 1 : login, 2 : mail, 3 : unit
#################################################################
proc agla_cua_get { valeur ch {crit 1}} {
   set liste [concat $astk::agla(infoid) $astk::agla(list_cua)]
   set pastrouve 1
   set nb [expr [llength $liste] / 4]
   for {set i 0} {$i < $nb} {incr i} {
      set log [lindex $liste [expr $i*4 + $crit]]
      set val [lindex $liste [expr $i*4 + $ch]]
      if { $valeur == $log } {
         set pastrouve 0
         break
      }
   }
   if { $pastrouve } {
      set val [ashare::mess ihm 239]
   }
   # exception pour reprer ceux qui n'ont pas accs  la mach_ref
   if { $valeur == "ASTER_LIBRE" } {
      set val $valeur
   }
   if { $ashare::dbg >= 4 } {
      ashare::log "<DEBUG> (agla_cua_get) IN($valeur,$ch) OUT($val)"
   }
   return $val
}

==> astk-client-1.3.0.1.tbz: aster/ASTK/ASTK_CLIENT/lib/ASTK/init_agla.tcl <==
#########################################################################
# COPYRIGHT (C) 2003         EDF R&D              WWW.CODE-ASTER.ORG    #
#                                                                       #
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR         #
# MODIFY IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS        #
# PUBLISHED BY THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE    #
# LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.                       #
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,       #
# BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF        #
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      #
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              #
#                                                                       #
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     #
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO : EDF R&D CODE_ASTER,       #
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.        #
#########################################################################

# $Id: init_agla.tcl,v 1.17 2005/10/28 11:07:49 mcourtoi Exp $

# initialisation des variables de l'agla
#################################################################
proc init_agla { } {
   set astk::agla(status) off
   set astk::agla(instance) "UA"
   set astk::agla(mail_ata) ""
   set astk::agla(infoid) {}
   set astk::agla(num_serv) -1
   set astk::agla(nb_verdev) 0
   set astk::agla(verdev,0) ""
   set astk::agla(rex_url) ""
   set astk::agla(rep_rex) ""
}

# mise  jour des donnes de l'agla
#################################################################
proc raffr_agla { {parent "."} {REINI "DETR"} } {
   ashare::mess "info" 5
   init_agla

#  vrifie que mach_dev est parmi les serveurs configurs
   set pastrouve 1
   for {set i 0} {$i < $astk::config(nb_serv)} {incr i} {
      if { $astk::config($i,mach_ref) == "oui" } {
         set astk::agla(num_serv) $i
         set pastrouve 0
         break
      }
   }
# machine de rfrence pas dans les serveurs
#ou on ne veut pas rcuprer les infos
   if { $pastrouve } {
      ashare::mess "info" 7
   } elseif { $astk::recup == 0 } {
      ashare::mess "info" 40
   } else {
# machine de rfrence trouve
      set serv $astk::agla(num_serv)
   # instance de l'utilisateur
      set astk::agla(status) off
      recup_info $parent $serv
      if { [regexp "EDA" $astk::agla(instance)] } {
         set astk::agla(status) on
      }

   # faire la liste des versions (les NEW de $serv)
      set astk::agla(nb_verdev) 0
      for {set i 0} {$i < $astk::config($serv,nb_vers)} {incr i} {
         if { [regexp {^NEW} $astk::config($serv,vers,$i)] } {
            set astk::agla(verdev,$astk::agla(nb_verdev)) $astk::config($serv,vers,$i)
            incr astk::agla(nb_verdev)
         }
      }
      if { $ashare::dbg >= 4 } {
         ashare::log "<DEBUG> (raffr_agla) status:$astk::agla(status) num_serv:$astk::agla(num_serv) instance:$astk::agla(instance)"
      }
   }
# mise  jour des onglets
   if { $REINI != "INI" } {
      init_onglet "DETR"
   }
}
